// SPDX-License-Identifier: GPL-2.0-only
/*
 * Copyright (c) 2018, The Linux Foundation. All rights reserved.
 * Copyright (c) 2022 Qualcomm Innovation Center, Inc. All rights reserved.
 */

#include <linux/regmap.h>
#include <linux/device.h>
#include "wcd939x-registers.h"

const u8 wcd939x_reg_access[WCD939X_NUM_REGISTERS] = {
	[WCD939X_REG(WCD939X_ANA_PAGE)]                       = RD_WR_REG,
	[WCD939X_REG(WCD939X_BIAS)]                           = RD_WR_REG,
	[WCD939X_REG(WCD939X_RX_SUPPLIES)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_HPH)]                            = RD_WR_REG,
	[WCD939X_REG(WCD939X_EAR)]                            = RD_WR_REG,
	[WCD939X_REG(WCD939X_EAR_COMPANDER_CTL)]              = RD_WR_REG,
	[WCD939X_REG(WCD939X_TX_CH1)]                         = RD_WR_REG,
	[WCD939X_REG(WCD939X_TX_CH2)]                         = RD_WR_REG,
	[WCD939X_REG(WCD939X_TX_CH3)]                         = RD_WR_REG,
	[WCD939X_REG(WCD939X_TX_CH4)]                         = RD_WR_REG,
	[WCD939X_REG(WCD939X_MICB1_MICB2_DSP_EN_LOGIC)]       = RD_WR_REG,
	[WCD939X_REG(WCD939X_MICB3_DSP_EN_LOGIC)]             = RD_WR_REG,
	[WCD939X_REG(WCD939X_MBHC_MECH)]                      = RD_WR_REG,
	[WCD939X_REG(WCD939X_MBHC_ELECT)]                     = RD_WR_REG,
	[WCD939X_REG(WCD939X_MBHC_ZDET)]                      = RD_WR_REG,
	[WCD939X_REG(WCD939X_MBHC_RESULT_1)]                  = RD_REG,
	[WCD939X_REG(WCD939X_MBHC_RESULT_2)]                  = RD_REG,
	[WCD939X_REG(WCD939X_MBHC_RESULT_3)]                  = RD_REG,
	[WCD939X_REG(WCD939X_MBHC_BTN0)]                      = RD_WR_REG,
	[WCD939X_REG(WCD939X_MBHC_BTN1)]                      = RD_WR_REG,
	[WCD939X_REG(WCD939X_MBHC_BTN2)]                      = RD_WR_REG,
	[WCD939X_REG(WCD939X_MBHC_BTN3)]                      = RD_WR_REG,
	[WCD939X_REG(WCD939X_MBHC_BTN4)]                      = RD_WR_REG,
	[WCD939X_REG(WCD939X_MBHC_BTN5)]                      = RD_WR_REG,
	[WCD939X_REG(WCD939X_MBHC_BTN6)]                      = RD_WR_REG,
	[WCD939X_REG(WCD939X_MBHC_BTN7)]                      = RD_WR_REG,
	[WCD939X_REG(WCD939X_MICB1)]                          = RD_WR_REG,
	[WCD939X_REG(WCD939X_MICB2)]                          = RD_WR_REG,
	[WCD939X_REG(WCD939X_MICB2_RAMP)]                     = RD_WR_REG,
	[WCD939X_REG(WCD939X_MICB3)]                          = RD_WR_REG,
	[WCD939X_REG(WCD939X_MICB4)]                          = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTL)]                            = RD_WR_REG,
	[WCD939X_REG(WCD939X_VBG_FINE_ADJ)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_VDDCX_ADJUST)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_DISABLE_LDOL)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTL_CLK)]                        = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTL_ANA)]                        = RD_WR_REG,
	[WCD939X_REG(WCD939X_ZDET_VNEG_CTL)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_ZDET_BIAS_CTL)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTL_BCS)]                        = RD_WR_REG,
	[WCD939X_REG(WCD939X_MOISTURE_DET_FSM_STATUS)]        = RD_REG,
	[WCD939X_REG(WCD939X_TEST_CTL)]                       = RD_WR_REG,
	[WCD939X_REG(WCD939X_MODE)]                           = RD_WR_REG,
	[WCD939X_REG(WCD939X_LDOH_BIAS)]                      = RD_WR_REG,
	[WCD939X_REG(WCD939X_STB_LOADS)]                      = RD_WR_REG,
	[WCD939X_REG(WCD939X_SLOWRAMP)]                       = RD_WR_REG,
	[WCD939X_REG(WCD939X_TEST_CTL_1)]                     = RD_WR_REG,
	[WCD939X_REG(WCD939X_TEST_CTL_2)]                     = RD_WR_REG,
	[WCD939X_REG(WCD939X_TEST_CTL_3)]                     = RD_WR_REG,
	[WCD939X_REG(WCD939X_MICB2_TEST_CTL_1)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_MICB2_TEST_CTL_2)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_MICB2_TEST_CTL_3)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_MICB3_TEST_CTL_1)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_MICB3_TEST_CTL_2)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_MICB3_TEST_CTL_3)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_MICB4_TEST_CTL_1)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_MICB4_TEST_CTL_2)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_MICB4_TEST_CTL_3)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_ADC_VCM)]                        = RD_WR_REG,
	[WCD939X_REG(WCD939X_BIAS_ATEST)]                     = RD_WR_REG,
	[WCD939X_REG(WCD939X_SPARE1)]                         = RD_WR_REG,
	[WCD939X_REG(WCD939X_SPARE2)]                         = RD_WR_REG,
	[WCD939X_REG(WCD939X_TXFE_DIV_CTL)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_TXFE_DIV_START)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_SPARE3)]                         = RD_WR_REG,
	[WCD939X_REG(WCD939X_SPARE4)]                         = RD_WR_REG,
	[WCD939X_REG(WCD939X_TEST_EN)]                        = RD_WR_REG,
	[WCD939X_REG(WCD939X_ADC_IB)]                         = RD_WR_REG,
	[WCD939X_REG(WCD939X_ATEST_REFCTL)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_TX_1_2_TEST_CTL)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_TEST_BLK_EN1)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_TXFE1_CLKDIV)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_SAR2_ERR)]                       = RD_REG,
	[WCD939X_REG(WCD939X_SAR1_ERR)]                       = RD_REG,
	[WCD939X_REG(WCD939X_TX_3_4_TEST_EN)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_TX_3_4_ADC_IB)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_TX_3_4_ATEST_REFCTL)]            = RD_WR_REG,
	[WCD939X_REG(WCD939X_TX_3_4_TEST_CTL)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_TEST_BLK_EN3)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_TXFE3_CLKDIV)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_SAR4_ERR)]                       = RD_REG,
	[WCD939X_REG(WCD939X_SAR3_ERR)]                       = RD_REG,
	[WCD939X_REG(WCD939X_TEST_BLK_EN2)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_TXFE2_CLKDIV)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_TX_3_4_SPARE1)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_TEST_BLK_EN4)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_TXFE4_CLKDIV)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_TX_3_4_SPARE2)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_MODE_1)]                         = RD_WR_REG,
	[WCD939X_REG(WCD939X_MODE_2)]                         = RD_WR_REG,
	[WCD939X_REG(WCD939X_MODE_3)]                         = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTRL_VCL_1)]                     = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTRL_VCL_2)]                     = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTRL_CCL_1)]                     = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTRL_CCL_2)]                     = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTRL_CCL_3)]                     = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTRL_CCL_4)]                     = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTRL_CCL_5)]                     = RD_WR_REG,
	[WCD939X_REG(WCD939X_BUCK_TMUX_A_D)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_BUCK_SW_DRV_CNTL)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_SPARE)]                          = RD_WR_REG,
	[WCD939X_REG(WCD939X_EN)]                             = RD_WR_REG,
	[WCD939X_REG(WCD939X_VNEG_CTRL_1)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_VNEG_CTRL_2)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_VNEG_CTRL_3)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_VNEG_CTRL_4)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_VNEG_CTRL_5)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_VNEG_CTRL_6)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_VNEG_CTRL_7)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_VNEG_CTRL_8)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_VNEG_CTRL_9)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_VNEGDAC_CTRL_1)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_VNEGDAC_CTRL_2)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_VNEGDAC_CTRL_3)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTRL_1)]                         = RD_WR_REG,
	[WCD939X_REG(WCD939X_FLYBACK_TEST_CTL)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_AUX_SW_CTL)]                     = RD_WR_REG,
	[WCD939X_REG(WCD939X_PA_AUX_IN_CONN)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_TIMER_DIV)]                      = RD_WR_REG,
	[WCD939X_REG(WCD939X_OCP_CTL)]                        = RD_WR_REG,
	[WCD939X_REG(WCD939X_OCP_COUNT)]                      = RD_WR_REG,
	[WCD939X_REG(WCD939X_BIAS_EAR_DAC)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_BIAS_EAR_AMP)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_BIAS_HPH_LDO)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_BIAS_HPH_PA)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_BIAS_HPH_RDACBUFF_CNP2)]         = RD_WR_REG,
	[WCD939X_REG(WCD939X_BIAS_HPH_RDAC_LDO)]              = RD_WR_REG,
	[WCD939X_REG(WCD939X_BIAS_HPH_CNP1)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_BIAS_HPH_LOWPOWER)]              = RD_WR_REG,
	[WCD939X_REG(WCD939X_BIAS_AUX_DAC)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_BIAS_AUX_AMP)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_BIAS_VNEGDAC_BLEEDER)]           = RD_WR_REG,
	[WCD939X_REG(WCD939X_BIAS_MISC)]                      = RD_WR_REG,
	[WCD939X_REG(WCD939X_BIAS_BUCK_RST)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_BIAS_BUCK_VREF_ERRAMP)]          = RD_WR_REG,
	[WCD939X_REG(WCD939X_BIAS_FLYB_ERRAMP)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_BIAS_FLYB_BUFF)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_BIAS_FLYB_MID_RST)]              = RD_WR_REG,
	[WCD939X_REG(WCD939X_L_STATUS)]                       = RD_REG,
	[WCD939X_REG(WCD939X_R_STATUS)]                       = RD_REG,
	[WCD939X_REG(WCD939X_CNP_EN)]                         = RD_WR_REG,
	[WCD939X_REG(WCD939X_CNP_WG_CTL)]                     = RD_WR_REG,
	[WCD939X_REG(WCD939X_CNP_WG_TIME)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_HPH_OCP_CTL)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_AUTO_CHOP)]                      = RD_WR_REG,
	[WCD939X_REG(WCD939X_CHOP_CTL)]                       = RD_WR_REG,
	[WCD939X_REG(WCD939X_PA_CTL1)]                        = RD_WR_REG,
	[WCD939X_REG(WCD939X_PA_CTL2)]                        = RD_WR_REG,
	[WCD939X_REG(WCD939X_L_EN)]                           = RD_WR_REG,
	[WCD939X_REG(WCD939X_L_TEST)]                         = RD_WR_REG,
	[WCD939X_REG(WCD939X_L_ATEST)]                        = RD_WR_REG,
	[WCD939X_REG(WCD939X_R_EN)]                           = RD_WR_REG,
	[WCD939X_REG(WCD939X_R_TEST)]                         = RD_WR_REG,
	[WCD939X_REG(WCD939X_R_ATEST)]                        = RD_WR_REG,
	[WCD939X_REG(WCD939X_RDAC_CLK_CTL1)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_RDAC_CLK_CTL2)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_RDAC_LDO_CTL)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_RDAC_CHOP_CLK_LP_CTL)]           = RD_WR_REG,
	[WCD939X_REG(WCD939X_REFBUFF_UHQA_CTL)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_REFBUFF_LP_CTL)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_L_DAC_CTL)]                      = RD_WR_REG,
	[WCD939X_REG(WCD939X_R_DAC_CTL)]                      = RD_WR_REG,
	[WCD939X_REG(WCD939X_HPHLR_SURGE_COMP_SEL)]           = RD_WR_REG,
	[WCD939X_REG(WCD939X_HPHLR_SURGE_EN)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_HPHLR_SURGE_MISC1)]              = RD_WR_REG,
	[WCD939X_REG(WCD939X_HPHLR_SURGE_STATUS)]             = RD_REG,
	[WCD939X_REG(WCD939X_EAR_EN_REG)]                     = RD_WR_REG,
	[WCD939X_REG(WCD939X_EAR_PA_CON)]                     = RD_WR_REG,
	[WCD939X_REG(WCD939X_EAR_SP_CON)]                     = RD_WR_REG,
	[WCD939X_REG(WCD939X_EAR_DAC_CON)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_EAR_CNP_FSM_CON)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_EAR_TEST_CTL)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_STATUS_REG_1)]                   = RD_REG,
	[WCD939X_REG(WCD939X_STATUS_REG_2)]                   = RD_REG,
	[WCD939X_REG(WCD939X_ANA_NEW_PAGE)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_ANA_HPH2)]                       = RD_WR_REG,
	[WCD939X_REG(WCD939X_ANA_HPH3)]                       = RD_WR_REG,
	[WCD939X_REG(WCD939X_SLEEP_CTL)]                      = RD_WR_REG,
	[WCD939X_REG(WCD939X_WATCHDOG_CTL)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_ELECT_REM_CLAMP_CTL)]            = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTL_1)]                          = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTL_2)]                          = RD_WR_REG,
	[WCD939X_REG(WCD939X_PLUG_DETECT_CTL)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_ZDET_ANA_CTL)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_ZDET_RAMP_CTL)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_FSM_STATUS)]                     = RD_REG,
	[WCD939X_REG(WCD939X_ADC_RESULT)]                     = RD_REG,
	[WCD939X_REG(WCD939X_TX_CH12_MUX)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_TX_CH34_MUX)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_DIE_CRK_DET_EN)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_DIE_CRK_DET_OUT)]                = RD_REG,
	[WCD939X_REG(WCD939X_RDAC_GAIN_CTL)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_PA_GAIN_CTL_L)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_RDAC_VREF_CTL)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_RDAC_OVERRIDE_CTL)]              = RD_WR_REG,
	[WCD939X_REG(WCD939X_PA_GAIN_CTL_R)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_PA_MISC1)]                       = RD_WR_REG,
	[WCD939X_REG(WCD939X_PA_MISC2)]                       = RD_WR_REG,
	[WCD939X_REG(WCD939X_PA_RDAC_MISC)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_HPH_TIMER1)]                     = RD_WR_REG,
	[WCD939X_REG(WCD939X_HPH_TIMER2)]                     = RD_WR_REG,
	[WCD939X_REG(WCD939X_HPH_TIMER3)]                     = RD_WR_REG,
	[WCD939X_REG(WCD939X_HPH_TIMER4)]                     = RD_WR_REG,
	[WCD939X_REG(WCD939X_PA_RDAC_MISC2)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_PA_RDAC_MISC3)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_RDAC_HD2_CTL_L)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_RDAC_HD2_CTL_R)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_HPH_RDAC_BIAS_LOHIFI)]           = RD_WR_REG,
	[WCD939X_REG(WCD939X_HPH_RDAC_BIAS_ULP)]              = RD_WR_REG,
	[WCD939X_REG(WCD939X_HPH_RDAC_LDO_LP)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_MOISTURE_DET_DC_CTRL)]           = RD_WR_REG,
	[WCD939X_REG(WCD939X_MOISTURE_DET_POLLING_CTRL)]      = RD_WR_REG,
	[WCD939X_REG(WCD939X_MECH_DET_CURRENT)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_ZDET_CLK_AND_MOISTURE_CTL_NEW)]  = RD_WR_REG,
	[WCD939X_REG(WCD939X_EAR_CHOPPER_CON)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_CNP_VCM_CON1)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_CNP_VCM_CON2)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_EAR_DYNAMIC_BIAS)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_WATCHDOG_CTL_1)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_WATCHDOG_CTL_2)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_DIE_CRK_DET_INT1)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_DIE_CRK_DET_INT2)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_TXFE_DIVSTOP_L2)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_TXFE_DIVSTOP_L1)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_TXFE_DIVSTOP_L0)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_TXFE_DIVSTOP_ULP1P2M)]           = RD_WR_REG,
	[WCD939X_REG(WCD939X_TXFE_DIVSTOP_ULP0P6M)]           = RD_WR_REG,
	[WCD939X_REG(WCD939X_TXFE_ICTRL_STG1_L2L1)]           = RD_WR_REG,
	[WCD939X_REG(WCD939X_TXFE_ICTRL_STG1_L0)]             = RD_WR_REG,
	[WCD939X_REG(WCD939X_TXFE_ICTRL_STG1_ULP)]            = RD_WR_REG,
	[WCD939X_REG(WCD939X_TXFE_ICTRL_STG2MAIN_L2L1)]       = RD_WR_REG,
	[WCD939X_REG(WCD939X_TXFE_ICTRL_STG2MAIN_L0)]         = RD_WR_REG,
	[WCD939X_REG(WCD939X_TXFE_ICTRL_STG2MAIN_ULP)]        = RD_WR_REG,
	[WCD939X_REG(WCD939X_TXFE_ICTRL_STG2CASC_L2L1L0)]     = RD_WR_REG,
	[WCD939X_REG(WCD939X_TXFE_ICTRL_STG2CASC_ULP)]        = RD_WR_REG,
	[WCD939X_REG(WCD939X_TXADC_SCBIAS_L2L1)]              = RD_WR_REG,
	[WCD939X_REG(WCD939X_TXADC_SCBIAS_L0ULP)]             = RD_WR_REG,
	[WCD939X_REG(WCD939X_TXADC_INT_L2)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_TXADC_INT_L1)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_TXADC_INT_L0)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_TXADC_INT_ULP)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_DIGITAL_PAGE)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_CHIP_ID0)]                       = RD_REG,
	[WCD939X_REG(WCD939X_CHIP_ID1)]                       = RD_REG,
	[WCD939X_REG(WCD939X_CHIP_ID2)]                       = RD_REG,
	[WCD939X_REG(WCD939X_CHIP_ID3)]                       = RD_REG,
	[WCD939X_REG(WCD939X_SWR_TX_CLK_RATE)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_RST_CTL)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_TOP_CLK_CFG)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_ANA_CLK_CTL)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_DIG_CLK_CTL)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_SWR_RST_EN)]                     = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_PATH_MODE)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_RX_RST)]                     = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_RX0_CTL)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_RX1_CTL)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_RX2_CTL)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_TX_ANA_MODE_0_1)]            = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_TX_ANA_MODE_2_3)]            = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_COMP_CTL_0)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_ANA_TX_CLK_CTL)]             = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_HPH_DSM_A1_0)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_HPH_DSM_A1_1)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_HPH_DSM_A2_0)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_HPH_DSM_A2_1)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_HPH_DSM_A3_0)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_HPH_DSM_A3_1)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_HPH_DSM_A4_0)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_HPH_DSM_A4_1)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_HPH_DSM_A5_0)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_HPH_DSM_A5_1)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_HPH_DSM_A6_0)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_HPH_DSM_A7_0)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_HPH_DSM_C_0)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_HPH_DSM_C_1)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_HPH_DSM_C_2)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_HPH_DSM_C_3)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_HPH_DSM_R1)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_HPH_DSM_R2)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_HPH_DSM_R3)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_HPH_DSM_R4)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_HPH_DSM_R5)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_HPH_DSM_R6)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_HPH_DSM_R7)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_EAR_DSM_A1_0)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_EAR_DSM_A1_1)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_EAR_DSM_A2_0)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_EAR_DSM_A2_1)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_EAR_DSM_A3_0)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_EAR_DSM_A3_1)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_EAR_DSM_A4_0)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_EAR_DSM_A4_1)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_EAR_DSM_A5_0)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_EAR_DSM_A5_1)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_EAR_DSM_A6_0)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_EAR_DSM_A7_0)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_EAR_DSM_C_0)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_EAR_DSM_C_1)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_EAR_DSM_C_2)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_EAR_DSM_C_3)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_EAR_DSM_R1)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_EAR_DSM_R2)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_EAR_DSM_R3)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_EAR_DSM_R4)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_EAR_DSM_R5)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_EAR_DSM_R6)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_EAR_DSM_R7)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_HPH_GAIN_RX_0)]              = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_HPH_GAIN_RX_1)]              = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_HPH_GAIN_DSD_0)]             = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_HPH_GAIN_DSD_1)]             = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_HPH_GAIN_DSD_2)]             = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_EAR_GAIN_DSD_0)]             = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_EAR_GAIN_DSD_1)]             = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_EAR_GAIN_DSD_2)]             = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_HPH_GAIN_CTL)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_EAR_GAIN_CTL)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_EAR_PATH_CTL)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_SWR_CLH)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_SWR_CLH_BYP)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_TX0_CTL)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_TX1_CTL)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_TX2_CTL)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_TX_RST)]                     = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_REQ_CTL)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_RST)]                        = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_AMIC_CTL)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_DMIC_CTL)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_DMIC1_CTL)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_DMIC2_CTL)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_DMIC3_CTL)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_DMIC4_CTL)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_EFUSE_PRG_CTL)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_EFUSE_CTL)]                      = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_DMIC_RATE_1_2)]              = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_DMIC_RATE_3_4)]              = RD_WR_REG,
	[WCD939X_REG(WCD939X_PDM_WD_CTL0)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_PDM_WD_CTL1)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_PDM_WD_CTL2)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_INTR_MODE)]                      = RD_WR_REG,
	[WCD939X_REG(WCD939X_INTR_MASK_0)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_INTR_MASK_1)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_INTR_MASK_2)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_INTR_STATUS_0)]                  = RD_REG,
	[WCD939X_REG(WCD939X_INTR_STATUS_1)]                  = RD_REG,
	[WCD939X_REG(WCD939X_INTR_STATUS_2)]                  = RD_REG,
	[WCD939X_REG(WCD939X_INTR_CLEAR_0)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_INTR_CLEAR_1)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_INTR_CLEAR_2)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_INTR_LEVEL_0)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_INTR_LEVEL_1)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_INTR_LEVEL_2)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_INTR_SET_0)]                     = RD_WR_REG,
	[WCD939X_REG(WCD939X_INTR_SET_1)]                     = RD_WR_REG,
	[WCD939X_REG(WCD939X_INTR_SET_2)]                     = RD_WR_REG,
	[WCD939X_REG(WCD939X_INTR_TEST_0)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_INTR_TEST_1)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_INTR_TEST_2)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_TX_MODE_DBG_EN)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_TX_MODE_DBG_0_1)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_TX_MODE_DBG_2_3)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_LB_IN_SEL_CTL)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_LOOP_BACK_MODE)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_SWR_DAC_TEST)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_SWR_HM_TEST_RX_0)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_SWR_HM_TEST_TX_0)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_SWR_HM_TEST_RX_1)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_SWR_HM_TEST_TX_1)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_SWR_HM_TEST_TX_2)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_SWR_HM_TEST_0)]                  = RD_REG,
	[WCD939X_REG(WCD939X_SWR_HM_TEST_1)]                  = RD_REG,
	[WCD939X_REG(WCD939X_PAD_CTL_SWR_0)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_PAD_CTL_SWR_1)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_I2C_CTL)]                        = RD_WR_REG,
	[WCD939X_REG(WCD939X_CDC_TX_TANGGU_SW_MODE)]          = RD_WR_REG,
	[WCD939X_REG(WCD939X_EFUSE_TEST_CTL_0)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_EFUSE_TEST_CTL_1)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_EFUSE_T_DATA_0)]                 = RD_REG,
	[WCD939X_REG(WCD939X_EFUSE_T_DATA_1)]                 = RD_REG,
	[WCD939X_REG(WCD939X_PAD_CTL_PDM_RX0)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_PAD_CTL_PDM_RX1)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_PAD_CTL_PDM_TX0)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_PAD_CTL_PDM_TX1)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_PAD_CTL_PDM_TX2)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_PAD_INP_DIS_0)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_PAD_INP_DIS_1)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_DRIVE_STRENGTH_0)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_DRIVE_STRENGTH_1)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_DRIVE_STRENGTH_2)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_RX_DATA_EDGE_CTL)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_TX_DATA_EDGE_CTL)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_GPIO_MODE)]                      = RD_WR_REG,
	[WCD939X_REG(WCD939X_PIN_CTL_OE)]                     = RD_WR_REG,
	[WCD939X_REG(WCD939X_PIN_CTL_DATA_0)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_PIN_CTL_DATA_1)]                 = RD_WR_REG,
	[WCD939X_REG(WCD939X_PIN_STATUS_0)]                   = RD_REG,
	[WCD939X_REG(WCD939X_PIN_STATUS_1)]                   = RD_REG,
	[WCD939X_REG(WCD939X_DIG_DEBUG_CTL)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_DIG_DEBUG_EN)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_ANA_CSR_DBG_ADD)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_ANA_CSR_DBG_CTL)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_SSP_DBG)]                        = RD_WR_REG,
	[WCD939X_REG(WCD939X_MODE_STATUS_0)]                  = RD_REG,
	[WCD939X_REG(WCD939X_MODE_STATUS_1)]                  = RD_REG,
	[WCD939X_REG(WCD939X_SPARE_0)]                        = RD_WR_REG,
	[WCD939X_REG(WCD939X_SPARE_1)]                        = RD_WR_REG,
	[WCD939X_REG(WCD939X_SPARE_2)]                        = RD_WR_REG,
	[WCD939X_REG(WCD939X_EFUSE_REG_0)]                    = RD_REG,
	[WCD939X_REG(WCD939X_EFUSE_REG_1)]                    = RD_REG,
	[WCD939X_REG(WCD939X_EFUSE_REG_2)]                    = RD_REG,
	[WCD939X_REG(WCD939X_EFUSE_REG_3)]                    = RD_REG,
	[WCD939X_REG(WCD939X_EFUSE_REG_4)]                    = RD_REG,
	[WCD939X_REG(WCD939X_EFUSE_REG_5)]                    = RD_REG,
	[WCD939X_REG(WCD939X_EFUSE_REG_6)]                    = RD_REG,
	[WCD939X_REG(WCD939X_EFUSE_REG_7)]                    = RD_REG,
	[WCD939X_REG(WCD939X_EFUSE_REG_8)]                    = RD_REG,
	[WCD939X_REG(WCD939X_EFUSE_REG_9)]                    = RD_REG,
	[WCD939X_REG(WCD939X_EFUSE_REG_10)]                   = RD_REG,
	[WCD939X_REG(WCD939X_EFUSE_REG_11)]                   = RD_REG,
	[WCD939X_REG(WCD939X_EFUSE_REG_12)]                   = RD_REG,
	[WCD939X_REG(WCD939X_EFUSE_REG_13)]                   = RD_REG,
	[WCD939X_REG(WCD939X_EFUSE_REG_14)]                   = RD_REG,
	[WCD939X_REG(WCD939X_EFUSE_REG_15)]                   = RD_REG,
	[WCD939X_REG(WCD939X_EFUSE_REG_16)]                   = RD_REG,
	[WCD939X_REG(WCD939X_EFUSE_REG_17)]                   = RD_REG,
	[WCD939X_REG(WCD939X_EFUSE_REG_18)]                   = RD_REG,
	[WCD939X_REG(WCD939X_EFUSE_REG_19)]                   = RD_REG,
	[WCD939X_REG(WCD939X_EFUSE_REG_20)]                   = RD_REG,
	[WCD939X_REG(WCD939X_EFUSE_REG_21)]                   = RD_REG,
	[WCD939X_REG(WCD939X_EFUSE_REG_22)]                   = RD_REG,
	[WCD939X_REG(WCD939X_EFUSE_REG_23)]                   = RD_REG,
	[WCD939X_REG(WCD939X_EFUSE_REG_24)]                   = RD_REG,
	[WCD939X_REG(WCD939X_EFUSE_REG_25)]                   = RD_REG,
	[WCD939X_REG(WCD939X_EFUSE_REG_26)]                   = RD_REG,
	[WCD939X_REG(WCD939X_EFUSE_REG_27)]                   = RD_REG,
	[WCD939X_REG(WCD939X_EFUSE_REG_28)]                   = RD_REG,
	[WCD939X_REG(WCD939X_EFUSE_REG_29)]                   = RD_REG,
	[WCD939X_REG(WCD939X_EFUSE_REG_30)]                   = RD_REG,
	[WCD939X_REG(WCD939X_EFUSE_REG_31)]                   = RD_REG,
	[WCD939X_REG(WCD939X_TX_REQ_FB_CTL_0)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_TX_REQ_FB_CTL_1)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_TX_REQ_FB_CTL_2)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_TX_REQ_FB_CTL_3)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_TX_REQ_FB_CTL_4)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_DEM_BYPASS_DATA0)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_DEM_BYPASS_DATA1)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_DEM_BYPASS_DATA2)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_DEM_BYPASS_DATA3)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_DEM_SECOND_ORDER)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_DSM_CTRL)]                       = RD_WR_REG,
	[WCD939X_REG(WCD939X_DSM_0_STATIC_DATA_0)]            = RD_WR_REG,
	[WCD939X_REG(WCD939X_DSM_0_STATIC_DATA_1)]            = RD_WR_REG,
	[WCD939X_REG(WCD939X_DSM_0_STATIC_DATA_2)]            = RD_WR_REG,
	[WCD939X_REG(WCD939X_DSM_0_STATIC_DATA_3)]            = RD_WR_REG,
	[WCD939X_REG(WCD939X_DSM_1_STATIC_DATA_0)]            = RD_WR_REG,
	[WCD939X_REG(WCD939X_DSM_1_STATIC_DATA_1)]            = RD_WR_REG,
	[WCD939X_REG(WCD939X_DSM_1_STATIC_DATA_2)]            = RD_WR_REG,
	[WCD939X_REG(WCD939X_DSM_1_STATIC_DATA_3)]            = RD_WR_REG,
	[WCD939X_REG(WCD939X_RX_TOP_PAGE)]                    = RD_WR_REG,
	[WCD939X_REG(WCD939X_TOP_CFG0)]                       = RD_WR_REG,
	[WCD939X_REG(WCD939X_HPHL_COMP_WR_LSB)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_HPHL_COMP_WR_MSB)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_HPHL_COMP_LUT)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_HPHL_COMP_RD_LSB)]               = RD_REG,
	[WCD939X_REG(WCD939X_HPHL_COMP_RD_MSB)]               = RD_REG,
	[WCD939X_REG(WCD939X_HPHR_COMP_WR_LSB)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_HPHR_COMP_WR_MSB)]               = RD_WR_REG,
	[WCD939X_REG(WCD939X_HPHR_COMP_LUT)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_HPHR_COMP_RD_LSB)]               = RD_REG,
	[WCD939X_REG(WCD939X_HPHR_COMP_RD_MSB)]               = RD_REG,
	[WCD939X_REG(WCD939X_DSD0_DEBUG_CFG1)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_DSD0_DEBUG_CFG2)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_DSD0_DEBUG_CFG3)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_DSD0_DEBUG_CFG4)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_DSD0_DEBUG_CFG5)]                = RD_REG,
	[WCD939X_REG(WCD939X_DSD0_DEBUG_CFG6)]                = RD_REG,
	[WCD939X_REG(WCD939X_DSD1_DEBUG_CFG1)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_DSD1_DEBUG_CFG2)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_DSD1_DEBUG_CFG3)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_DSD1_DEBUG_CFG4)]                = RD_WR_REG,
	[WCD939X_REG(WCD939X_DSD1_DEBUG_CFG5)]                = RD_REG,
	[WCD939X_REG(WCD939X_DSD1_DEBUG_CFG6)]                = RD_REG,
	[WCD939X_REG(WCD939X_HPHL_RX_PATH_CFG0)]              = RD_WR_REG,
	[WCD939X_REG(WCD939X_HPHL_RX_PATH_CFG1)]              = RD_WR_REG,
	[WCD939X_REG(WCD939X_HPHR_RX_PATH_CFG0)]              = RD_WR_REG,
	[WCD939X_REG(WCD939X_HPHR_RX_PATH_CFG1)]              = RD_WR_REG,
	[WCD939X_REG(WCD939X_RX_PATH_CFG2)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_HPHL_RX_PATH_SEC0)]              = RD_WR_REG,
	[WCD939X_REG(WCD939X_HPHL_RX_PATH_SEC1)]              = RD_WR_REG,
	[WCD939X_REG(WCD939X_HPHL_RX_PATH_SEC2)]              = RD_WR_REG,
	[WCD939X_REG(WCD939X_HPHL_RX_PATH_SEC3)]              = RD_WR_REG,
	[WCD939X_REG(WCD939X_HPHR_RX_PATH_SEC0)]              = RD_WR_REG,
	[WCD939X_REG(WCD939X_HPHR_RX_PATH_SEC1)]              = RD_WR_REG,
	[WCD939X_REG(WCD939X_HPHR_RX_PATH_SEC2)]              = RD_WR_REG,
	[WCD939X_REG(WCD939X_HPHR_RX_PATH_SEC3)]              = RD_WR_REG,
	[WCD939X_REG(WCD939X_RX_PATH_SEC4)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_RX_PATH_SEC5)]                   = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTL0)]                           = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTL1)]                           = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTL2)]                           = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTL3)]                           = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTL4)]                           = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTL5)]                           = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTL6)]                           = RD_REG,
	[WCD939X_REG(WCD939X_CTL7)]                           = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTL8)]                           = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTL9)]                           = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTL10)]                          = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTL11)]                          = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTL12)]                          = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTL13)]                          = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTL14)]                          = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTL15)]                          = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTL16)]                          = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTL17)]                          = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTL18)]                          = RD_WR_REG,
	[WCD939X_REG(WCD939X_CTL19)]                          = RD_WR_REG,
	[WCD939X_REG(WCD939X_R_CTL0)]                         = RD_WR_REG,
	[WCD939X_REG(WCD939X_R_CTL1)]                         = RD_WR_REG,
	[WCD939X_REG(WCD939X_R_CTL2)]                         = RD_WR_REG,
	[WCD939X_REG(WCD939X_R_CTL3)]                         = RD_WR_REG,
	[WCD939X_REG(WCD939X_R_CTL4)]                         = RD_WR_REG,
	[WCD939X_REG(WCD939X_R_CTL5)]                         = RD_WR_REG,
	[WCD939X_REG(WCD939X_R_CTL6)]                         = RD_REG,
	[WCD939X_REG(WCD939X_R_CTL7)]                         = RD_WR_REG,
	[WCD939X_REG(WCD939X_R_CTL8)]                         = RD_WR_REG,
	[WCD939X_REG(WCD939X_R_CTL9)]                         = RD_WR_REG,
	[WCD939X_REG(WCD939X_R_CTL10)]                        = RD_WR_REG,
	[WCD939X_REG(WCD939X_R_CTL11)]                        = RD_WR_REG,
	[WCD939X_REG(WCD939X_R_CTL12)]                        = RD_WR_REG,
	[WCD939X_REG(WCD939X_R_CTL13)]                        = RD_WR_REG,
	[WCD939X_REG(WCD939X_R_CTL14)]                        = RD_WR_REG,
	[WCD939X_REG(WCD939X_R_CTL15)]                        = RD_WR_REG,
	[WCD939X_REG(WCD939X_R_CTL16)]                        = RD_WR_REG,
	[WCD939X_REG(WCD939X_R_CTL17)]                        = RD_WR_REG,
	[WCD939X_REG(WCD939X_R_CTL18)]                        = RD_WR_REG,
	[WCD939X_REG(WCD939X_R_CTL19)]                        = RD_WR_REG,
	[WCD939X_REG(WCD939X_PATH_CTL)]                       = RD_WR_REG,
	[WCD939X_REG(WCD939X_CFG0)]                           = RD_WR_REG,
	[WCD939X_REG(WCD939X_CFG1)]                           = RD_WR_REG,
	[WCD939X_REG(WCD939X_CFG2)]                           = RD_WR_REG,
	[WCD939X_REG(WCD939X_CFG3)]                           = RD_WR_REG,
	[WCD939X_REG(WCD939X_DSD_HPHL_PATH_CTL)]              = RD_WR_REG,
	[WCD939X_REG(WCD939X_DSD_HPHL_CFG0)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_DSD_HPHL_CFG1)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_DSD_HPHL_CFG2)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_DSD_HPHL_CFG3)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_CFG4)]                           = RD_WR_REG,
	[WCD939X_REG(WCD939X_CFG5)]                           = RD_WR_REG,
	[WCD939X_REG(WCD939X_DSD_HPHR_PATH_CTL)]              = RD_WR_REG,
	[WCD939X_REG(WCD939X_DSD_HPHR_CFG0)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_DSD_HPHR_CFG1)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_DSD_HPHR_CFG2)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_DSD_HPHR_CFG3)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_DSD_HPHR_CFG4)]                  = RD_WR_REG,
	[WCD939X_REG(WCD939X_DSD_HPHR_CFG5)]                  = RD_WR_REG,
};
