// SPDX-License-Identifier: GPL-2.0-only
/*
 * Copyright (c) 2021, The Linux Foundation. All rights reserved.
 */

#include <linux/regmap.h>
#include <linux/device.h>
#include "wsa884x-registers.h"

const u8 wsa884x_reg_access[WSA884X_NUM_REGISTERS] = {
	[WSA884X_REG(WSA884X_BG_CTRL)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_ADC_CTRL)]                       = RD_WR_REG,
	[WSA884X_REG(WSA884X_BOP1_PROG)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_BOP2_PROG)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_UVLO_PROG)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_UVLO_PROG1)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_SPARE_CTRL_0)]                   = RD_WR_REG,
	[WSA884X_REG(WSA884X_SPARE_CTRL_1)]                   = RD_WR_REG,
	[WSA884X_REG(WSA884X_SPARE_CTRL_2)]                   = RD_WR_REG,
	[WSA884X_REG(WSA884X_SPARE_CTRL_3)]                   = RD_WR_REG,
	[WSA884X_REG(WSA884X_REF_CTRL)]                       = RD_WR_REG,
	[WSA884X_REG(WSA884X_BG_TEST_CTL)]                    = RD_WR_REG,
	[WSA884X_REG(WSA884X_BG_BIAS)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_ADC_PROG)]                       = RD_WR_REG,
	[WSA884X_REG(WSA884X_ADC_IREF_CTL)]                   = RD_WR_REG,
	[WSA884X_REG(WSA884X_ADC_ISENS_CTL)]                  = RD_WR_REG,
	[WSA884X_REG(WSA884X_ADC_CLK_CTL)]                    = RD_WR_REG,
	[WSA884X_REG(WSA884X_ADC_TEST_CTL)]                   = RD_WR_REG,
	[WSA884X_REG(WSA884X_ADC_BIAS)]                       = RD_WR_REG,
	[WSA884X_REG(WSA884X_VBAT_SNS)]                       = RD_WR_REG,
	[WSA884X_REG(WSA884X_DOUT_MSB)]                       = RD_REG,
	[WSA884X_REG(WSA884X_DOUT_LSB)]                       = RD_REG,
	[WSA884X_REG(WSA884X_BOP_ATEST_SEL)]                  = RD_WR_REG,
	[WSA884X_REG(WSA884X_MISC0)]                          = RD_WR_REG,
	[WSA884X_REG(WSA884X_MISC1)]                          = RD_WR_REG,
	[WSA884X_REG(WSA884X_MISC2)]                          = RD_WR_REG,
	[WSA884X_REG(WSA884X_MISC3)]                          = RD_WR_REG,
	[WSA884X_REG(WSA884X_SPARE_TSBG_0)]                   = RD_WR_REG,
	[WSA884X_REG(WSA884X_SPARE_TUNE_0)]                   = RD_WR_REG,
	[WSA884X_REG(WSA884X_SPARE_TUNE_1)]                   = RD_WR_REG,
	[WSA884X_REG(WSA884X_VSENSE1)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_ISENSE2)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_SPARE_CTL_1)]                    = RD_WR_REG,
	[WSA884X_REG(WSA884X_SPARE_CTL_2)]                    = RD_WR_REG,
	[WSA884X_REG(WSA884X_SPARE_CTL_3)]                    = RD_WR_REG,
	[WSA884X_REG(WSA884X_SPARE_CTL_4)]                    = RD_WR_REG,
	[WSA884X_REG(WSA884X_EN)]                             = RD_WR_REG,
	[WSA884X_REG(WSA884X_OVERRIDE1)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_OVERRIDE2)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_ISENSE1)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_ISENSE_CAL)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_MISC)]                           = RD_WR_REG,
	[WSA884X_REG(WSA884X_ADC_0)]                          = RD_WR_REG,
	[WSA884X_REG(WSA884X_ADC_1)]                          = RD_WR_REG,
	[WSA884X_REG(WSA884X_ADC_2)]                          = RD_WR_REG,
	[WSA884X_REG(WSA884X_ADC_3)]                          = RD_WR_REG,
	[WSA884X_REG(WSA884X_ADC_4)]                          = RD_WR_REG,
	[WSA884X_REG(WSA884X_ADC_5)]                          = RD_WR_REG,
	[WSA884X_REG(WSA884X_ADC_6)]                          = RD_WR_REG,
	[WSA884X_REG(WSA884X_ADC_7)]                          = RD_WR_REG,
	[WSA884X_REG(WSA884X_STATUS)]                         = RD_REG,
	[WSA884X_REG(WSA884X_IVSENSE_SPARE_TUNE_1)]           = RD_WR_REG,
	[WSA884X_REG(WSA884X_SPARE_TUNE_2)]                   = RD_WR_REG,
	[WSA884X_REG(WSA884X_SPARE_TUNE_3)]                   = RD_WR_REG,
	[WSA884X_REG(WSA884X_SPARE_TUNE_4)]                   = RD_WR_REG,
	[WSA884X_REG(WSA884X_TOP_CTRL1)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_CLIP_DET_CTRL1)]                 = RD_WR_REG,
	[WSA884X_REG(WSA884X_CLIP_DET_CTRL2)]                 = RD_WR_REG,
	[WSA884X_REG(WSA884X_DAC_CTRL1)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_DAC_VCM_CTRL_REG1)]              = RD_WR_REG,
	[WSA884X_REG(WSA884X_DAC_VCM_CTRL_REG2)]              = RD_WR_REG,
	[WSA884X_REG(WSA884X_DAC_VCM_CTRL_REG3)]              = RD_WR_REG,
	[WSA884X_REG(WSA884X_DAC_VCM_CTRL_REG4)]              = RD_WR_REG,
	[WSA884X_REG(WSA884X_DAC_VCM_CTRL_REG5)]              = RD_WR_REG,
	[WSA884X_REG(WSA884X_DAC_VCM_CTRL_REG6)]              = RD_WR_REG,
	[WSA884X_REG(WSA884X_PWM_CLK_CTL)]                    = RD_WR_REG,
	[WSA884X_REG(WSA884X_DRV_LF_LDO_SEL)]                 = RD_WR_REG,
	[WSA884X_REG(WSA884X_OCP_CTL)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_PDRV_HS_CTL)]                    = RD_WR_REG,
	[WSA884X_REG(WSA884X_PDRV_LS_CTL)]                    = RD_WR_REG,
	[WSA884X_REG(WSA884X_SPK_TOP_SPARE_CTL_1)]            = RD_WR_REG,
	[WSA884X_REG(WSA884X_SPK_TOP_SPARE_CTL_2)]            = RD_WR_REG,
	[WSA884X_REG(WSA884X_SPK_TOP_SPARE_CTL_3)]            = RD_WR_REG,
	[WSA884X_REG(WSA884X_SPK_TOP_SPARE_CTL_4)]            = RD_WR_REG,
	[WSA884X_REG(WSA884X_SPARE_CTL_5)]                    = RD_WR_REG,
	[WSA884X_REG(WSA884X_DAC_EN_DEBUG_REG)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_DAC_OPAMP_BIAS1_REG)]            = RD_WR_REG,
	[WSA884X_REG(WSA884X_DAC_OPAMP_BIAS2_REG)]            = RD_WR_REG,
	[WSA884X_REG(WSA884X_DAC_TUNE1)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_DAC_VOLTAGE_CTRL_REG)]           = RD_WR_REG,
	[WSA884X_REG(WSA884X_ATEST1_REG)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_ATEST2_REG)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_TOP_BIAS_REG1)]                  = RD_WR_REG,
	[WSA884X_REG(WSA884X_TOP_BIAS_REG2)]                  = RD_WR_REG,
	[WSA884X_REG(WSA884X_TOP_BIAS_REG3)]                  = RD_WR_REG,
	[WSA884X_REG(WSA884X_TOP_BIAS_REG4)]                  = RD_WR_REG,
	[WSA884X_REG(WSA884X_PWRSTG_DBG2)]                    = RD_WR_REG,
	[WSA884X_REG(WSA884X_DRV_LF_BLK_EN)]                  = RD_WR_REG,
	[WSA884X_REG(WSA884X_DRV_LF_EN)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_DRV_LF_MASK_DCC_CTL)]            = RD_WR_REG,
	[WSA884X_REG(WSA884X_DRV_LF_MISC_CTL1)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_DRV_LF_REG_GAIN)]                = RD_WR_REG,
	[WSA884X_REG(WSA884X_DRV_OS_CAL_CTL)]                 = RD_WR_REG,
	[WSA884X_REG(WSA884X_DRV_OS_CAL_CTL1)]                = RD_WR_REG,
	[WSA884X_REG(WSA884X_PWRSTG_DBG)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_BBM_CTL)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_TOP_MISC1)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_DAC_VCM_CTRL_REG7)]              = RD_WR_REG,
	[WSA884X_REG(WSA884X_TOP_BIAS_REG5)]                  = RD_WR_REG,
	[WSA884X_REG(WSA884X_DRV_LF_MISC_CTL2)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_SPK_TOP_SPARE_TUNE_2)]           = RD_REG,
	[WSA884X_REG(WSA884X_SPK_TOP_SPARE_TUNE_3)]           = RD_REG,
	[WSA884X_REG(WSA884X_SPK_TOP_SPARE_TUNE_4)]           = RD_REG,
	[WSA884X_REG(WSA884X_SPARE_TUNE_5)]                   = RD_REG,
	[WSA884X_REG(WSA884X_SPARE_TUNE_6)]                   = RD_REG,
	[WSA884X_REG(WSA884X_SPARE_TUNE_7)]                   = RD_REG,
	[WSA884X_REG(WSA884X_SPARE_TUNE_8)]                   = RD_REG,
	[WSA884X_REG(WSA884X_SPARE_TUNE_9)]                   = RD_REG,
	[WSA884X_REG(WSA884X_SPARE_TUNE_10)]                  = RD_REG,
	[WSA884X_REG(WSA884X_PA_STATUS0)]                     = RD_REG,
	[WSA884X_REG(WSA884X_PA_STATUS1)]                     = RD_REG,
	[WSA884X_REG(WSA884X_PA_STATUS2)]                     = RD_REG,
	[WSA884X_REG(WSA884X_PA_STATUS3)]                     = RD_REG,
	[WSA884X_REG(WSA884X_PA_STATUS4)]                     = RD_REG,
	[WSA884X_REG(WSA884X_PA_STATUS5)]                     = RD_REG,
	[WSA884X_REG(WSA884X_SPARE_RO_1)]                     = RD_REG,
	[WSA884X_REG(WSA884X_SPARE_RO_2)]                     = RD_REG,
	[WSA884X_REG(WSA884X_SPARE_RO_3)]                     = RD_REG,
	[WSA884X_REG(WSA884X_STB_CTRL1)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_CURRENT_LIMIT)]                  = RD_WR_REG,
	[WSA884X_REG(WSA884X_BYP_CTRL1)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_SPARE_CTL_0)]                    = RD_WR_REG,
	[WSA884X_REG(WSA884X_BOOST_SPARE_CTL_1)]              = RD_WR_REG,
	[WSA884X_REG(WSA884X_SPARE_RO_0)]                     = RD_REG,
	[WSA884X_REG(WSA884X_BOOST_SPARE_RO_1)]               = RD_REG,
	[WSA884X_REG(WSA884X_IBIAS1)]                         = RD_WR_REG,
	[WSA884X_REG(WSA884X_IBIAS2)]                         = RD_WR_REG,
	[WSA884X_REG(WSA884X_IBIAS3)]                         = RD_WR_REG,
	[WSA884X_REG(WSA884X_EN_CTRL)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_STB_CTRL2)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_STB_CTRL3)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_STB_CTRL4)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_BYP_CTRL2)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_BYP_CTRL3)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_ZX_CTRL1)]                       = RD_WR_REG,
	[WSA884X_REG(WSA884X_ZX_CTRL2)]                       = RD_WR_REG,
	[WSA884X_REG(WSA884X_BLEEDER_CTRL)]                   = RD_WR_REG,
	[WSA884X_REG(WSA884X_BOOST_MISC)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_PWRSTAGE_CTRL1)]                 = RD_WR_REG,
	[WSA884X_REG(WSA884X_PWRSTAGE_CTRL2)]                 = RD_WR_REG,
	[WSA884X_REG(WSA884X_PWRSTAGE_CTRL3)]                 = RD_WR_REG,
	[WSA884X_REG(WSA884X_PWRSTAGE_CTRL4)]                 = RD_WR_REG,
	[WSA884X_REG(WSA884X_MAXD_REG1)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_MAXD_REG2)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_ILIM_CTRL1)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_ILIM_CTRL2)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_TEST_CTRL1)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_TEST_CTRL2)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_SPARE1)]                         = RD_WR_REG,
	[WSA884X_REG(WSA884X_BOOT_CAP_CHECK)]                 = RD_WR_REG,
	[WSA884X_REG(WSA884X_PON_CTL_0)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_PWRSAV_CTL)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_PON_LDOL_SPARE_CTL_0)]           = RD_WR_REG,
	[WSA884X_REG(WSA884X_PON_LDOL_SPARE_CTL_1)]           = RD_WR_REG,
	[WSA884X_REG(WSA884X_PON_LDOL_SPARE_CTL_2)]           = RD_WR_REG,
	[WSA884X_REG(WSA884X_PON_LDOL_SPARE_CTL_3)]           = RD_WR_REG,
	[WSA884X_REG(WSA884X_PON_CLT_1)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_PON_CTL_2)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_PON_CTL_3)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_CKWD_CTL_0)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_CKWD_CTL_1)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_CKWD_CTL_2)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_CKSK_CTL_0)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_PADSW_CTL_0)]                    = RD_WR_REG,
	[WSA884X_REG(WSA884X_TEST_0)]                         = RD_WR_REG,
	[WSA884X_REG(WSA884X_TEST_1)]                         = RD_WR_REG,
	[WSA884X_REG(WSA884X_STATUS_0)]                       = RD_REG,
	[WSA884X_REG(WSA884X_STATUS_1)]                       = RD_REG,
	[WSA884X_REG(WSA884X_PON_LDOL_SPARE_TUNE_0)]          = RD_WR_REG,
	[WSA884X_REG(WSA884X_PON_LDOL_SPARE_TUNE_1)]          = RD_WR_REG,
	[WSA884X_REG(WSA884X_PON_LDOL_SPARE_TUNE_2)]          = RD_WR_REG,
	[WSA884X_REG(WSA884X_PON_LDOL_SPARE_TUNE_3)]          = RD_WR_REG,
	[WSA884X_REG(WSA884X_PON_LDOL_SPARE_TUNE_4)]          = RD_WR_REG,
	[WSA884X_REG(WSA884X_DIG_CTRL0_PAGE)]                 = RD_WR_REG,
	[WSA884X_REG(WSA884X_CHIP_ID0)]                       = RD_REG,
	[WSA884X_REG(WSA884X_CHIP_ID1)]                       = RD_REG,
	[WSA884X_REG(WSA884X_CHIP_ID2)]                       = RD_REG,
	[WSA884X_REG(WSA884X_CHIP_ID3)]                       = RD_REG,
	[WSA884X_REG(WSA884X_BUS_ID)]                         = RD_REG,
	[WSA884X_REG(WSA884X_CDC_RST_CTL)]                    = RD_WR_REG,
	[WSA884X_REG(WSA884X_SWR_RESET_EN)]                   = RD_WR_REG,
	[WSA884X_REG(WSA884X_TOP_CLK_CFG)]                    = RD_WR_REG,
	[WSA884X_REG(WSA884X_SWR_CLK_RATE)]                   = RD_WR_REG,
	[WSA884X_REG(WSA884X_CDC_PATH_MODE)]                  = RD_WR_REG,
	[WSA884X_REG(WSA884X_CDC_CLK_CTL)]                    = RD_WR_REG,
	[WSA884X_REG(WSA884X_PA_FSM_EN)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_PA_FSM_CTL0)]                    = RD_WR_REG,
	[WSA884X_REG(WSA884X_PA_FSM_CTL1)]                    = RD_WR_REG,
	[WSA884X_REG(WSA884X_PA_FSM_TIMER0)]                  = RD_WR_REG,
	[WSA884X_REG(WSA884X_PA_FSM_TIMER1)]                  = RD_WR_REG,
	[WSA884X_REG(WSA884X_PA_FSM_STA0)]                    = RD_REG,
	[WSA884X_REG(WSA884X_PA_FSM_STA1)]                    = RD_REG,
	[WSA884X_REG(WSA884X_PA_FSM_ERR_CTL)]                 = RD_WR_REG,
	[WSA884X_REG(WSA884X_PA_FSM_ERR_COND0)]               = RD_REG,
	[WSA884X_REG(WSA884X_PA_FSM_ERR_COND1)]               = RD_REG,
	[WSA884X_REG(WSA884X_PA_FSM_MSK0)]                    = RD_WR_REG,
	[WSA884X_REG(WSA884X_PA_FSM_MSK1)]                    = RD_WR_REG,
	[WSA884X_REG(WSA884X_PA_FSM_BYP_CTL)]                 = RD_WR_REG,
	[WSA884X_REG(WSA884X_PA_FSM_BYP0)]                    = RD_WR_REG,
	[WSA884X_REG(WSA884X_PA_FSM_BYP1)]                    = RD_WR_REG,
	[WSA884X_REG(WSA884X_TADC_VALUE_CTL)]                 = RD_WR_REG,
	[WSA884X_REG(WSA884X_TEMP_DETECT_CTL)]                = RD_WR_REG,
	[WSA884X_REG(WSA884X_TEMP_DIN_MSB)]                   = RD_REG,
	[WSA884X_REG(WSA884X_TEMP_DIN_LSB)]                   = RD_REG,
	[WSA884X_REG(WSA884X_TEMP_DOUT_MSB)]                  = RD_REG,
	[WSA884X_REG(WSA884X_TEMP_DOUT_LSB)]                  = RD_REG,
	[WSA884X_REG(WSA884X_TEMP_CONFIG0)]                   = RD_WR_REG,
	[WSA884X_REG(WSA884X_TEMP_CONFIG1)]                   = RD_WR_REG,
	[WSA884X_REG(WSA884X_VBAT_THRM_FLT_CTL)]              = RD_WR_REG,
	[WSA884X_REG(WSA884X_VBAT_CAL_CTL)]                   = RD_WR_REG,
	[WSA884X_REG(WSA884X_VBAT_DIN_MSB)]                   = RD_REG,
	[WSA884X_REG(WSA884X_VBAT_DIN_LSB)]                   = RD_REG,
	[WSA884X_REG(WSA884X_VBAT_DOUT_MSB)]                  = RD_REG,
	[WSA884X_REG(WSA884X_VBAT_DOUT_LSB)]                  = RD_REG,
	[WSA884X_REG(WSA884X_VBAT_CAL_MSB)]                   = RD_REG,
	[WSA884X_REG(WSA884X_VBAT_CAL_LSB)]                   = RD_REG,
	[WSA884X_REG(WSA884X_UVLO_DEGLITCH_CTL)]              = RD_WR_REG,
	[WSA884X_REG(WSA884X_BOP_DEGLITCH_CTL)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_VBAT_ZONE_DETC_CTL)]             = RD_WR_REG,
	[WSA884X_REG(WSA884X_CPS_CTL)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_CDC_RX_CTL)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_CDC_SPK_DSM_A1_0)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_CDC_SPK_DSM_A1_1)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_CDC_SPK_DSM_A2_0)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_CDC_SPK_DSM_A2_1)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_CDC_SPK_DSM_A3_0)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_CDC_SPK_DSM_A3_1)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_CDC_SPK_DSM_A4_0)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_CDC_SPK_DSM_A4_1)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_CDC_SPK_DSM_A5_0)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_CDC_SPK_DSM_A5_1)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_CDC_SPK_DSM_A6_0)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_CDC_SPK_DSM_A7_0)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_CDC_SPK_DSM_C_0)]                = RD_WR_REG,
	[WSA884X_REG(WSA884X_CDC_SPK_DSM_C_1)]                = RD_WR_REG,
	[WSA884X_REG(WSA884X_CDC_SPK_DSM_C_2)]                = RD_WR_REG,
	[WSA884X_REG(WSA884X_CDC_SPK_DSM_C_3)]                = RD_WR_REG,
	[WSA884X_REG(WSA884X_CDC_SPK_DSM_R1)]                 = RD_WR_REG,
	[WSA884X_REG(WSA884X_CDC_SPK_DSM_R2)]                 = RD_WR_REG,
	[WSA884X_REG(WSA884X_CDC_SPK_DSM_R3)]                 = RD_WR_REG,
	[WSA884X_REG(WSA884X_CDC_SPK_DSM_R4)]                 = RD_WR_REG,
	[WSA884X_REG(WSA884X_CDC_SPK_DSM_R5)]                 = RD_WR_REG,
	[WSA884X_REG(WSA884X_CDC_SPK_DSM_R6)]                 = RD_WR_REG,
	[WSA884X_REG(WSA884X_CDC_SPK_DSM_R7)]                 = RD_WR_REG,
	[WSA884X_REG(WSA884X_CDC_SPK_GAIN_PDM_0)]             = RD_WR_REG,
	[WSA884X_REG(WSA884X_CDC_SPK_GAIN_PDM_1)]             = RD_WR_REG,
	[WSA884X_REG(WSA884X_CDC_SPK_GAIN_PDM_2)]             = RD_WR_REG,
	[WSA884X_REG(WSA884X_PDM_WD_CTL)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_DEM_BYPASS_DATA0)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_DEM_BYPASS_DATA1)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_DEM_BYPASS_DATA2)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_DEM_BYPASS_DATA3)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_DRE_CTL_0)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_DRE_CTL_1)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_DRE_IDLE_DET_CTL)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_GAIN_RAMPING_CTL)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_GAIN_RAMPING_MIN)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_TAGC_CTL)]                       = RD_WR_REG,
	[WSA884X_REG(WSA884X_TAGC_TIME)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_TAGC_FORCE_VAL)]                 = RD_WR_REG,
	[WSA884X_REG(WSA884X_VAGC_CTL)]                       = RD_WR_REG,
	[WSA884X_REG(WSA884X_VAGC_TIME)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_VAGC_ATTN_LVL_1)]                = RD_WR_REG,
	[WSA884X_REG(WSA884X_VAGC_ATTN_LVL_2)]                = RD_WR_REG,
	[WSA884X_REG(WSA884X_VAGC_ATTN_LVL_3)]                = RD_WR_REG,
	[WSA884X_REG(WSA884X_CLSH_CTL_0)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_CLSH_CTL_1)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_CLSH_V_HD_PA)]                   = RD_WR_REG,
	[WSA884X_REG(WSA884X_CLSH_V_PA_MIN)]                  = RD_WR_REG,
	[WSA884X_REG(WSA884X_CLSH_OVRD_VAL)]                  = RD_WR_REG,
	[WSA884X_REG(WSA884X_CLSH_HARD_MAX)]                  = RD_WR_REG,
	[WSA884X_REG(WSA884X_CLSH_SOFT_MAX)]                  = RD_WR_REG,
	[WSA884X_REG(WSA884X_CLSH_SIG_DP)]                    = RD_WR_REG,
	[WSA884X_REG(WSA884X_PBR_DELAY_CTL)]                  = RD_WR_REG,
	[WSA884X_REG(WSA884X_CLSH_SRL_MAX_PBR)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_CLSH_VTH1)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_CLSH_VTH2)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_CLSH_VTH3)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_CLSH_VTH4)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_CLSH_VTH5)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_CLSH_VTH6)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_CLSH_VTH7)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_CLSH_VTH8)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_CLSH_VTH9)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_CLSH_VTH10)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_CLSH_VTH11)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_CLSH_VTH12)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_CLSH_VTH13)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_CLSH_VTH14)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_CLSH_VTH15)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_DIG_CTRL1_PAGE)]                 = RD_WR_REG,
	[WSA884X_REG(WSA884X_VPHX_SYS_EN_STATUS)]             = RD_REG,
	[WSA884X_REG(WSA884X_ANA_WO_CTL_0)]                   = RD_WR_REG,
	[WSA884X_REG(WSA884X_ANA_WO_CTL_1)]                   = RD_WR_REG,
	[WSA884X_REG(WSA884X_PIN_CTL)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_PIN_CTL_OE)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_PIN_WDATA_IOPAD)]                = RD_WR_REG,
	[WSA884X_REG(WSA884X_PIN_STATUS)]                     = RD_REG,
	[WSA884X_REG(WSA884X_I2C_SLAVE_CTL)]                  = RD_WR_REG,
	[WSA884X_REG(WSA884X_SPMI_PAD_CTL0)]                  = RD_WR_REG,
	[WSA884X_REG(WSA884X_SPMI_PAD_CTL1)]                  = RD_WR_REG,
	[WSA884X_REG(WSA884X_SPMI_PAD_CTL2)]                  = RD_WR_REG,
	[WSA884X_REG(WSA884X_MEM_CTL)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_SWR_HM_TEST0)]                   = RD_WR_REG,
	[WSA884X_REG(WSA884X_SWR_HM_TEST1)]                   = RD_REG,
	[WSA884X_REG(WSA884X_OTP_CTRL0)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_CTRL1)]                      = RD_REG,
	[WSA884X_REG(WSA884X_OTP_CTRL2)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_STAT)]                       = RD_REG,
	[WSA884X_REG(WSA884X_OTP_PRG_TCSP0)]                  = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_PRG_TCSP1)]                  = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_PRG_TPPS)]                   = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_PRG_TVPS)]                   = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_PRG_TVPH)]                   = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_PRG_TPPR0)]                  = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_PRG_TPPR1)]                  = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_PRG_TPPH)]                   = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_PRG_END)]                    = RD_WR_REG,
	[WSA884X_REG(WSA884X_WAVG_PLAY)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_WAVG_CTL)]                       = RD_WR_REG,
	[WSA884X_REG(WSA884X_WAVG_LRA_PER_0)]                 = RD_WR_REG,
	[WSA884X_REG(WSA884X_WAVG_LRA_PER_1)]                 = RD_WR_REG,
	[WSA884X_REG(WSA884X_WAVG_DELTA_THETA_0)]             = RD_WR_REG,
	[WSA884X_REG(WSA884X_WAVG_DELTA_THETA_1)]             = RD_WR_REG,
	[WSA884X_REG(WSA884X_WAVG_DIRECT_AMP_0)]              = RD_WR_REG,
	[WSA884X_REG(WSA884X_WAVG_DIRECT_AMP_1)]              = RD_WR_REG,
	[WSA884X_REG(WSA884X_WAVG_PTRN_AMP0_0)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_WAVG_PTRN_AMP0_1)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_WAVG_PTRN_AMP1_0)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_WAVG_PTRN_AMP1_1)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_WAVG_PTRN_AMP2_0)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_WAVG_PTRN_AMP2_1)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_WAVG_PTRN_AMP3_0)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_WAVG_PTRN_AMP3_1)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_WAVG_PTRN_AMP4_0)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_WAVG_PTRN_AMP4_1)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_WAVG_PTRN_AMP5_0)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_WAVG_PTRN_AMP5_1)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_WAVG_PTRN_AMP6_0)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_WAVG_PTRN_AMP6_1)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_WAVG_PTRN_AMP7_0)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_WAVG_PTRN_AMP7_1)]               = RD_WR_REG,
	[WSA884X_REG(WSA884X_WAVG_PER_0_1)]                   = RD_WR_REG,
	[WSA884X_REG(WSA884X_WAVG_PER_2_3)]                   = RD_WR_REG,
	[WSA884X_REG(WSA884X_WAVG_PER_4_5)]                   = RD_WR_REG,
	[WSA884X_REG(WSA884X_WAVG_PER_6_7)]                   = RD_WR_REG,
	[WSA884X_REG(WSA884X_WAVG_STA)]                       = RD_REG,
	[WSA884X_REG(WSA884X_INTR_MODE)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_INTR_MASK0)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_INTR_MASK1)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_INTR_STATUS0)]                   = RD_REG,
	[WSA884X_REG(WSA884X_INTR_STATUS1)]                   = RD_REG,
	[WSA884X_REG(WSA884X_INTR_CLEAR0)]                    = RD_WR_REG,
	[WSA884X_REG(WSA884X_INTR_CLEAR1)]                    = RD_WR_REG,
	[WSA884X_REG(WSA884X_INTR_LEVEL0)]                    = RD_WR_REG,
	[WSA884X_REG(WSA884X_INTR_LEVEL1)]                    = RD_WR_REG,
	[WSA884X_REG(WSA884X_INTR_SET0)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_INTR_SET1)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_INTR_TEST0)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_INTR_TEST1)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_PDM_TEST_MODE)]                  = RD_WR_REG,
	[WSA884X_REG(WSA884X_ATE_TEST_MODE)]                  = RD_REG,
	[WSA884X_REG(WSA884X_PA_FSM_DBG)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_DIG_DEBUG_MODE)]                 = RD_WR_REG,
	[WSA884X_REG(WSA884X_DIG_DEBUG_SEL)]                  = RD_WR_REG,
	[WSA884X_REG(WSA884X_DIG_DEBUG_EN)]                   = RD_WR_REG,
	[WSA884X_REG(WSA884X_TADC_DETECT_DBG_CTL)]            = RD_WR_REG,
	[WSA884X_REG(WSA884X_TADC_DEBUG_MSB)]                 = RD_WR_REG,
	[WSA884X_REG(WSA884X_TADC_DEBUG_LSB)]                 = RD_WR_REG,
	[WSA884X_REG(WSA884X_SAMPLE_EDGE_SEL)]                = RD_WR_REG,
	[WSA884X_REG(WSA884X_SWR_EDGE_SEL)]                   = RD_WR_REG,
	[WSA884X_REG(WSA884X_TEST_MODE_CTL)]                  = RD_WR_REG,
	[WSA884X_REG(WSA884X_IOPAD_CTL)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_ANA_CSR_DBG_ADD)]                = RD_WR_REG,
	[WSA884X_REG(WSA884X_ANA_CSR_DBG_CTL)]                = RD_WR_REG,
	[WSA884X_REG(WSA884X_CLK_DBG_CTL)]                    = RD_WR_REG,
	[WSA884X_REG(WSA884X_SPARE_R)]                        = RD_REG,
	[WSA884X_REG(WSA884X_SPARE_0)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_SPARE_1)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_SPARE_2)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_SCODE)]                          = RD_WR_REG,
	[WSA884X_REG(WSA884X_DIG_TRIM_PAGE)]                  = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_0)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_1)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_2)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_3)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_4)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_5)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_6)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_7)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_8)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_9)]                      = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_10)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_11)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_12)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_13)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_14)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_15)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_16)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_17)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_18)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_19)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_20)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_21)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_22)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_23)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_24)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_25)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_26)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_27)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_28)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_29)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_30)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_31)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_32)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_33)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_34)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_35)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_36)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_37)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_38)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_39)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_40)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_41)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_OTP_REG_63)]                     = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_0)]                         = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_1)]                         = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_2)]                         = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_3)]                         = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_4)]                         = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_5)]                         = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_6)]                         = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_7)]                         = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_8)]                         = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_9)]                         = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_10)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_11)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_12)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_13)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_14)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_15)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_16)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_17)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_18)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_19)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_20)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_21)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_22)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_23)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_24)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_25)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_26)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_27)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_28)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_29)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_30)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_31)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_32)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_33)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_34)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_35)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_36)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_37)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_38)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_39)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_40)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_41)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_42)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_43)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_44)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_45)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_46)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_47)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_48)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_49)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_50)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_51)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_52)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_53)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_54)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_55)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_56)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_57)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_58)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_59)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_60)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_61)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_62)]                        = RD_WR_REG,
	[WSA884X_REG(WSA884X_EMEM_63)]                        = RD_WR_REG,
};
